<?php
/**
 * @package   DPBexio
 * @copyright Copyright (C) 2022 Digital Peak GmbH. <https://www.digital-peak.com>
 * @license   https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 */

namespace DigitalPeak\Library\DPBexio\Bexio;

use DigitalPeak\ThinHTTPInterface;
use Joomla\Registry\Registry;

class API implements APIInterface
{
	/** @var ThinHTTPInterface $http */
	private $http;

	public function __construct(ThinHTTPInterface $http)
	{
		$this->http = $http;
	}

	/**
	 * Calls the Bexio API for the given path and the params. The returned array contains the
	 * data.
	 *
	 * @params string $path
	 * @params array  $params
	 * @params string $method
	 *
	 * @return array|\stdclass
	 */
	public function callBexioAPI(string $path, array $params, Registry $config, string $method = 'get')
	{
		$response = $this->http->request(
			'https://api.bexio.com' . $path,
			$params ? json_encode($params) : null,
			$config->get('api_token'),
			null,
			['Accept: application/json'],
			[],
			$method
		);

		// Check for errors in the response
		if (!empty($response->error_code)) {
			throw new \Exception(
				'Error on request ' . $path . ': ' . $response->message . ' ' . (!empty($response->errors) ? implode(', ', $response->errors) : ''),
				$response->error_code
			);
		}

		// Check the status code
		if ($response->dp->info->http_code >= 400) {
			throw new \Exception('Invalid response', $response->dp->info->http_code);
		}

		// Return the data
		return $response;
	}
}
